==> kubernetes-model-1.0.30-sources.jar: io/fabric8/openshift/api/model/DeploymentCauseImageTriggerBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class DeploymentCauseImageTriggerBuilder extends DeploymentCauseImageTriggerFluentImpl<DeploymentCauseImageTriggerBuilder> implements VisitableBuilder<DeploymentCauseImageTrigger,DeploymentCauseImageTriggerBuilder>{

     DeploymentCauseImageTriggerFluent<?> fluent;
public DeploymentCauseImageTriggerBuilder(){
    this(new DeploymentCauseImageTrigger());
}
public DeploymentCauseImageTriggerBuilder( DeploymentCauseImageTriggerFluent<?> fluent ){
    this(fluent, new DeploymentCauseImageTrigger());
}
public DeploymentCauseImageTriggerBuilder( DeploymentCauseImageTriggerFluent<?> fluent , DeploymentCauseImageTrigger instance ){
    this.fluent = fluent; fluent.withFrom(instance.getFrom()); 
}
public DeploymentCauseImageTriggerBuilder( DeploymentCauseImageTrigger instance ){
    this.fluent = this; this.withFrom(instance.getFrom()); 
}

public EditableDeploymentCauseImageTrigger build(){
    EditableDeploymentCauseImageTrigger buildable = new EditableDeploymentCauseImageTrigger(fluent.getFrom());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
DeploymentCauseImageTriggerBuilder that = (DeploymentCauseImageTriggerBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.51-sources.jar: io/fabric8/openshift/api/model/DeploymentCauseImageTriggerBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class DeploymentCauseImageTriggerBuilder extends DeploymentCauseImageTriggerFluentImpl<DeploymentCauseImageTriggerBuilder> implements VisitableBuilder<DeploymentCauseImageTrigger,DeploymentCauseImageTriggerBuilder>{

     DeploymentCauseImageTriggerFluent<?> fluent;
public DeploymentCauseImageTriggerBuilder(){
    this(new DeploymentCauseImageTrigger());
}
public DeploymentCauseImageTriggerBuilder( DeploymentCauseImageTriggerFluent<?> fluent ){
    this(fluent, new DeploymentCauseImageTrigger());
}
public DeploymentCauseImageTriggerBuilder( DeploymentCauseImageTriggerFluent<?> fluent , DeploymentCauseImageTrigger instance ){
    this.fluent = fluent; fluent.withFrom(instance.getFrom()); 
}
public DeploymentCauseImageTriggerBuilder( DeploymentCauseImageTrigger instance ){
    this.fluent = this; this.withFrom(instance.getFrom()); 
}

public DeploymentCauseImageTrigger build(){
    DeploymentCauseImageTrigger buildable = new DeploymentCauseImageTrigger(fluent.getFrom());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
DeploymentCauseImageTriggerBuilder that = (DeploymentCauseImageTriggerBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
